{
    rho = thermo.rho();

    volScalarField rAU(1.0/UEqn.A());
    U = rAU*UEqn.H();

    phi =
	fvc::interpolate(rho)
       *(
	    (fvc::interpolate(U) & mesh.Sf())
	  + fvc::ddtPhiCorr(rAU, rho, U, phi)
	);

    fvScalarMatrix pDDtEqn
    (
        fvc::ddt(rho) + psi*correction(fvm::ddt(p))
      + fvc::div(phi)
     ==
        parcels.Srho()
    );

    while (pimple.correctNonOrthogonal())
    {
        fvScalarMatrix pEqn
        (
            pDDtEqn
          - fvm::laplacian(rho*rAU, p)
        );

        pEqn.solve
        (
            mesh.solver(p.select(pimple.finalInnerIter()))
        );

        if (pimple.finalNonOrthogonalIter())
        {
            phi += pEqn.flux();
        }
    }

    p.relax();

    #include "rhoEqn.H" // NOTE: flux and time scales now inconsistent
    #include "compressibleContinuityErrs.H"

    U -= rAU*fvc::grad(p);
    U.correctBoundaryConditions();

    rho = thermo.rho();
    rho = max(rho, rhoMin);
    rho = min(rho, rhoMax);

    Info<< "p min/max = " << min(p).value() << ", " << max(p).value() << endl;
}
